"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatFile = exports.formatFileContent = void 0;
const loadExistingFile_1 = require("./loadExistingFile");
const writeAndAddFile_1 = require("./writeAndAddFile");
const prettier_1 = require("prettier");
const addCorrectSuffix = (file) => {
    if (file.endsWith("pre-commit")) {
        return file + ".sh";
    }
    if (file.endsWith("flake.lock")) {
        return file + ".json";
    }
    return file;
};
const formatFileContent = (content, file) => __awaiter(void 0, void 0, void 0, function* () {
    const transformedFile = addCorrectSuffix(file);
    const fileInfo = yield (0, prettier_1.getFileInfo)(transformedFile);
    if (!fileInfo.inferredParser) {
        return content;
    }
    const formattedContent = (0, prettier_1.format)(content, {
        filepath: transformedFile,
        arrowParens: "avoid",
        bracketSpacing: true,
        embeddedLanguageFormatting: "auto",
        htmlWhitespaceSensitivity: "css",
        insertPragma: false,
        bracketSameLine: false,
        jsxSingleQuote: false,
        printWidth: 120,
        proseWrap: "always",
        quoteProps: "consistent",
        requirePragma: false,
        semi: false,
        singleQuote: false,
        tabWidth: 2,
        trailingComma: "es5",
        useTabs: false,
        vueIndentScriptAndStyle: false,
    });
    return formattedContent;
});
exports.formatFileContent = formatFileContent;
const formatFile = (config, file) => __awaiter(void 0, void 0, void 0, function* () {
    const content = yield (0, loadExistingFile_1.loadExistingFile)(config, file).catch(() => undefined);
    if (!content)
        return;
    const formattedContent = yield (0, exports.formatFileContent)(content, file);
    if (formattedContent === content)
        return;
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, file, formattedContent);
});
exports.formatFile = formatFile;
