"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.augmentJsonConfig = exports.createJsonConfig = void 0;
const loadExistingFile_1 = require("./loadExistingFile");
const writeAndAddFile_1 = require("./writeAndAddFile");
const sortAndStringify_1 = require("../sortAndStringify");
/** Write a new json config / overwrite an existing one. The new config can be a function processing the previous one*/
const createJsonConfig = (config, file, newConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const sourceFile = yield (0, loadExistingFile_1.loadExistingFile)(config, file);
    const sourceObject = sourceFile && JSON.parse(sourceFile);
    const modified = typeof newConfig === "function" ? yield newConfig(sourceObject) : newConfig;
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, file, JSON.stringify(modified, null, 2));
});
exports.createJsonConfig = createJsonConfig;
/** Specify a second jsonfile that gets deepmerged into the file */
const augmentJsonConfig = (config, file, newConfig) => __awaiter(void 0, void 0, void 0, function* () {
    return (0, exports.createJsonConfig)(config, file, oldConfig => mergeJsonObjects(oldConfig, typeof newConfig === "function" ? newConfig(oldConfig) : newConfig));
});
exports.augmentJsonConfig = augmentJsonConfig;
/** Deepmerge two json objects. To delete a key specify `undefined`. Arrays get joined and deduplicated */
const mergeJsonObjects = (old, changes) => {
    if (Array.isArray(old) && Array.isArray(changes)) {
        const newArray = [...old, ...changes];
        const uniqueArray = newArray
            .map(value => (0, sortAndStringify_1.sortAndStringify)(value))
            .flatMap((v, i, a) => (a.indexOf(v) === i ? [newArray[i]] : []));
        return uniqueArray;
    }
    if (typeof old === "object" && typeof changes === "object" && old !== null && changes !== null) {
        const oldRecord = old;
        const changesRecord = changes;
        const keys = [...Object.keys(oldRecord), ...Object.keys(changesRecord)];
        const newEntries = keys.map(key => [
            key,
            Object.hasOwn(changesRecord, key) ? mergeJsonObjects(oldRecord[key], changesRecord[key]) : oldRecord[key],
        ]);
        return Object.fromEntries(newEntries);
    }
    return changes;
};
