"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTypescriptThing = void 0;
const commitUpdate_1 = require("./helpers/commitUpdate");
const generateConfig_1 = require("./helpers/generateConfig");
const prepareGitRepo_1 = require("./helpers/prepareGitRepo");
const prepareTargetDir_1 = require("./helpers/prepareTargetDir");
const addEmotion_1 = require("./steps/addEmotion");
const addEslint_1 = require("./steps/addEslint");
const addHusky_1 = require("./steps/addHusky");
const addJest_1 = require("./steps/addJest");
const addLintStaged_1 = require("./steps/addLintStaged");
const addNixShell_1 = require("./steps/addNixShell");
const addPrettier_1 = require("./steps/addPrettier");
const addReact_1 = require("./steps/addReact");
const addTypescript_1 = require("./steps/addTypescript");
const addVscodeSettings_1 = require("./steps/addVscodeSettings");
const initializeProject_1 = require("./steps/initializeProject");
const setupApplication_1 = require("./steps/setupApplication");
const setupLibrary_1 = require("./steps/setupLibrary");
const setupNextJs_1 = require("./steps/setupNextJs");
const setupReactComponent_1 = require("./steps/setupReactComponent");
const createTypescriptThing = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const { name, description, type, gitOrigin, gitBranch = "main", authorName, authorEmail } = options;
    const config = yield (0, generateConfig_1.generateConfig)(options);
    try {
        yield (0, prepareTargetDir_1.prepareTargetDir)(config);
        yield (0, prepareGitRepo_1.prepareGitRepo)(config, gitOrigin, gitBranch);
        yield (0, addNixShell_1.addNixShell)(config);
        yield (0, initializeProject_1.initializeProject)(config, name, "0.0.0", description, authorName, authorEmail, "MIT");
        yield (0, addTypescript_1.addTypescript)(config);
        yield (0, addPrettier_1.addPrettier)(config);
        yield (0, addEslint_1.addEslint)(config);
        yield (0, addJest_1.addJest)(config);
        if (config.gitCommits || config.gitRepo) {
            yield (0, addLintStaged_1.addLintStaged)(config);
        }
        else {
            config.logger.logMessage("Not installing lint-staged because git is disabled", { type: "info" });
        }
        if (config.gitRepo) {
            yield (0, addHusky_1.addHusky)(config);
        }
        yield (0, addVscodeSettings_1.addVscodeSettings)(config);
        if (type === "reactcomponent" || type === "nextjs") {
            yield (0, addReact_1.addReact)(config);
            yield (0, addEmotion_1.addEmotion)(config);
        }
        if (type === "library") {
            yield (0, setupLibrary_1.setupLibrary)(config);
        }
        if (type === "application") {
            yield (0, setupApplication_1.setupApplication)(config);
        }
        if (type === "reactcomponent") {
            yield (0, setupReactComponent_1.setupReactComponent)(config);
        }
        if (type === "nextjs") {
            yield (0, setupNextJs_1.setupNextJs)(config);
        }
        if (config.update) {
            yield (0, commitUpdate_1.commitUpdate)(config);
        }
        config.logger.logMessage("Created typescript thing successfully", { type: "success" });
    }
    catch (e) {
        if (e instanceof Error) {
            config.logger.logMessage(e.message, { type: "error" });
        }
        throw e;
    }
});
exports.createTypescriptThing = createTypescriptThing;
exports.default = exports.createTypescriptThing;
