"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addReact = void 0;
const commitWithAuthor_1 = require("../helpers/commitWithAuthor");
const installPackage_1 = require("../helpers/installPackage");
const modifyJsonFile_1 = require("../helpers/modifyJsonFile");
const withStateLogger_1 = require("../helpers/withStateLogger");
const writeAndAddFile_1 = require("../helpers/writeAndAddFile");
exports.addReact = (0, withStateLogger_1.withStateLogger)({ id: "react" }, (config) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, installPackage_1.installPackage)(config, ["react", "react-dom"], { prod: true });
    yield (0, installPackage_1.installPackage)(config, [
        "@types/react",
        "@types/react-dom",
        "jest-environment-jsdom",
        "@testing-library/react",
        "@testing-library/jest-dom",
        "eslint-plugin-jsx-a11y",
        "eslint-plugin-react",
        "eslint-plugin-react-hooks",
    ]);
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, ".eslintrc.json", {
        extends: [
            "plugin:react/recommended",
            "plugin:react/jsx-runtime",
            "plugin:react-hooks/recommended",
            "plugin:jsx-a11y/recommended",
        ],
        plugins: ["react", "react-hooks", "jsx-a11y"],
        rules: {
            "react/no-unknown-property": "off",
            "react/prop-types": "off",
        },
        settings: { react: { version: "detect" } },
    });
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, "tsconfig.json", {
        compilerOptions: {
            lib: ["DOM", "DOM.Iterable"],
            jsx: "react-jsx",
        },
    });
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, "jest.config.json", {
        testEnvironment: "jsdom",
        setupFilesAfterEnv: ["<rootDir>/jest-setup.ts"],
    });
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "jest-setup.ts", generateJestSetup());
    yield (0, commitWithAuthor_1.commitWithAuthor)(config, "Install react");
}));
const generateJestSetup = () => {
    return `// eslint-disable-next-line import/no-unassigned-import
  import "@testing-library/jest-dom"`;
};
