"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupApplication = void 0;
const addScriptToPackage_1 = require("../helpers/addScriptToPackage");
const commitWithAuthor_1 = require("../helpers/commitWithAuthor");
const installPackage_1 = require("../helpers/installPackage");
const modifyJsonFile_1 = require("../helpers/modifyJsonFile");
const withStateLogger_1 = require("../helpers/withStateLogger");
const writeAndAddFile_1 = require("../helpers/writeAndAddFile");
exports.setupApplication = (0, withStateLogger_1.withStateLogger)({
    id: "application",
    message: "Configuring project as a cli application",
    failed: "Failed to configure cli application",
    completed: "Configured project as a cli application",
}, (config) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, installPackage_1.installPackage)(config, ["@zebreus/resolve-tspaths"]);
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, "package.json", oldConfig => ({
        files: ["dist/**"],
        keywords: ["cli", "application", "interactive"],
        main: "dist/index.js",
        bin: {
            [oldConfig.name || "unknown"]: "dist/index.js",
        },
    }));
    const launchConfig = {
        version: "0.2.0",
        configurations: [
            {
                type: "node",
                request: "launch",
                name: "Debug application",
                program: "${workspaceFolder}/src/index.ts",
                runtimeArgs: ["--loader", "ts-node/esm", "--loader", "@zebreus/resolve-tspaths/esm"],
                console: "integratedTerminal",
                internalConsoleOptions: "openOnSessionStart",
            },
        ],
    };
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, ".vscode/launch.json", launchConfig);
    yield (0, addScriptToPackage_1.appendScriptToPackage)(config, "build", "sed '1s;^;#!/usr/bin/env node\\\\n;' dist/index.js -i && chmod a+x dist/index.js");
    yield (0, addScriptToPackage_1.appendScriptToPackage)(config, "prepack", "sed '1s;^;#!/usr/bin/env node\\\\n;' dist/index.js -i && chmod a+x dist/index.js");
    yield (0, addScriptToPackage_1.addScriptToPackage)(config, "start", "node --loader ts-node/esm --loader @zebreus/resolve-tspaths/esm 'index.js'");
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "src/index.ts", generateApplicationIndex());
    yield (0, commitWithAuthor_1.commitWithAuthor)(config, "Setup project as cli application");
}));
const generateApplicationIndex = () => {
    return `console.log("You launched the application!")
  
  export {}`;
};
