"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupNextJs = void 0;
const addJsExportFile_1 = require("../helpers/addJsExportFile");
const addScriptToPackage_1 = require("../helpers/addScriptToPackage");
const addToGitIgnore_1 = require("../helpers/addToGitIgnore");
const commitWithAuthor_1 = require("../helpers/commitWithAuthor");
const installPackage_1 = require("../helpers/installPackage");
const modifyJsonFile_1 = require("../helpers/modifyJsonFile");
const withStateLogger_1 = require("../helpers/withStateLogger");
const writeAndAddFile_1 = require("../helpers/writeAndAddFile");
exports.setupNextJs = (0, withStateLogger_1.withStateLogger)({
    id: "nextjs",
    message: "Configuring nextjs project",
    failed: "Failed to configure nextjs",
    completed: "Configured project as nextjs",
}, (config) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, installPackage_1.installPackage)(config, ["next"], { prod: true });
    yield (0, installPackage_1.installPackage)(config, ["@next/eslint-plugin-next"]);
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, "tsconfig.json", {
        compilerOptions: {
            jsx: "preserve",
            incremental: true,
            allowJs: false,
        },
        include: ["next-env.d.ts", "next.config.js"],
    });
    yield (0, writeAndAddFile_1.deleteAndAddFile)(config, "tsconfig.build.json");
    const nextConfig = {
        reactStrictMode: true,
        swcMinify: true,
    };
    yield (0, addJsExportFile_1.addESMExportFile)(config, "next.config.mjs", nextConfig);
    yield (0, addToGitIgnore_1.addToGitIgnore)(config, "next", ["next-env.d.ts", ".vercel", "/.next", "/out", "/build", ".env*.local"]);
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, "package.json", {
        keywords: ["nextjs"],
    });
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, ".eslintrc.json", {
        extends: ["plugin:@next/next/core-web-vitals"],
        rules: {
            "jsx-a11y/alt-text": [
                "error",
                {
                    elements: ["img"],
                    img: ["Image"],
                },
            ],
        },
    });
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "src/pages/index.tsx", getIndexPage());
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "src/components/Demo.tsx", getDemoComponent());
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "src/hooks/useToggle.ts", getToggleHook());
    yield (0, addScriptToPackage_1.addScriptToPackage)(config, "start", "next dev");
    yield (0, addScriptToPackage_1.addScriptToPackage)(config, "start:build", "next start");
    yield (0, addScriptToPackage_1.addScriptToPackage)(config, "build", "next build");
    yield (0, commitWithAuthor_1.commitWithAuthor)(config, "Setup nextjs app");
}));
const getIndexPage = () => `import { Demo } from "components/Demo"

const Page = () => {
  return (
    <div>
      <h1>My page</h1>
      <p>Content</p>
      <Demo />
    </div>
  )
}

export default Page`;
const getDemoComponent = () => `import { css } from "@emotion/react"
import { useToggle } from "hooks/useToggle"

export const Demo = () => {
  const [state, toggle] = useToggle()
  
  return (
    <button onClick={toggle}
      css={css\`
        background-color: \${state ? "red" : "blue"};
      \`}
    >
      Click to toggle color
    </button>
  )
}`;
const getToggleHook = () => `import { useCallback, useState } from "react"

export const useToggle = (initialState = false) => {
  const [state, setState] = useState(initialState)
  const toggle = useCallback(() => setState(state => !state), [])
  return [state, toggle] as const
}`;
