"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupReactComponent = void 0;
const addScriptToPackage_1 = require("../helpers/addScriptToPackage");
const commitWithAuthor_1 = require("../helpers/commitWithAuthor");
const installPackage_1 = require("../helpers/installPackage");
const modifyJsonFile_1 = require("../helpers/modifyJsonFile");
const withStateLogger_1 = require("../helpers/withStateLogger");
const writeAndAddFile_1 = require("../helpers/writeAndAddFile");
exports.setupReactComponent = (0, withStateLogger_1.withStateLogger)({
    id: "reactcomponent",
    message: "Configuring project as react component",
    failed: "Failed to configure as react component",
    completed: "Configured project as react component",
}, (config) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, installPackage_1.installPackage)(config, ["@ladle/react"]);
    yield (0, installPackage_1.installPackage)(config, ["react", "react-dom"], { peer: true });
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, "tsconfig.json", {
        compilerOptions: {
            jsx: "react-jsx",
            jsxImportSource: "@emotion/react",
        },
    });
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, "tsconfig.build.json", {
        exclude: ["**/*.stories.tsx?"],
    });
    yield (0, modifyJsonFile_1.augmentJsonConfig)(config, "package.json", {
        files: ["dist/**"],
        keywords: ["react", "component"],
        main: "dist/index.js",
    });
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "src/index.ts", generateComponentIndex());
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "src/Button.tsx", generateDemoButton());
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "src/tests/button.test.tsx", generateButtonTest());
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "src/Button.stories.tsx", generateButtonStory());
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, "vite.config.ts", generateViteConfig());
    yield (0, addScriptToPackage_1.addScriptToPackage)(config, "start", "ladle serve");
    yield (0, commitWithAuthor_1.commitWithAuthor)(config, "Setup react component");
}));
const generateComponentIndex = () => {
    return `export { Button } from "Button"`;
};
const generateDemoButton = () => {
    return `import { css } from "@emotion/react"

export type ButtonProps = {
  text?: string
  onClick?: () => void
}
export const Button = ({ text, onClick }: ButtonProps) => (
  <button
    css={css\`
      position: relative;
      background-color: transparent;
      padding: 0.4rem 0.8rem;
      border: 2px solid #333;
      text-align: center;
      transition: all 0.35s;

      &:hover {
        color: white;
      }

      &:before {
        position: absolute;
        content: "";
        inset: 0;
        width: 0;
        background: #ff003b;
        transition: all 0.35s;
        z-index: -1;
      }

      &:hover:before {
        width: 100%;
      }
    \`}
    onClick={onClick}
  >
    {text ?? ""}
  </button>
)`;
};
const generateButtonTest = () => {
    return `import { fireEvent, render, screen } from "@testing-library/react"
import { Button } from "Button"

it("is actually a button", () => {
  const testMessage = "Test Message"
  render(<Button text={testMessage} />)

  expect(screen.queryByText(testMessage)).toBeInstanceOf(HTMLButtonElement)
})

it("calls onClick on clicks", () => {
  const onClick = jest.fn()
  render(<Button onClick={onClick} />)

  const buttonElement = screen.queryByRole("button")
  expect(buttonElement).toBeTruthy()
  if (!buttonElement) throw new Error()

  expect(onClick).toHaveBeenCalledTimes(0)
  fireEvent.click(buttonElement)
  expect(onClick).toHaveBeenCalledTimes(1)
})`;
};
const generateButtonStory = () => `import { Button } from "Button"

export const Demo = () => <Button text="TestText" />`;
const generateViteConfig = () => `import react from "@vitejs/plugin-react"
import { defineConfig } from "vite"

export default defineConfig({
  plugins: [
    react({
      jsxImportSource: "@emotion/react",
    }),
  ],
  esbuild: {
    jsx: "automatic",
  },
  optimizeDeps: {
    include: ["@emotion/react/jsx-dev-runtime"],
  },
})`;
